@@ -1,7 +1,7 @@
 #include "kmplayertypes.cpp"
 #include "triestring.cpp"
 #include "kmplayerplaylist.cpp"
-#include "mediaobject.cpp"
+#include "actor.cpp"
 #include "kmplayer_rss.cpp"
 #include "kmplayer_atom.cpp"
 #include "kmplayer_asx.cpp"
