@@ -48,7 +48,7 @@ public:
     Imfl (NodePtr & d);
     ~Imfl ();
     KDE_NO_EXPORT virtual const char * nodeName () const { return "imfl"; }
-    virtual NodePtr childFromTag (const String & tag);
+    virtual Node *childFromTag (const String & tag);
     virtual void closed ();
     virtual void defer ();      // start loading the images if not yet done
     virtual void activate ();   // start timings, handle paint events
