@@ -35,6 +35,7 @@ namespace KMPlayer {
 
 class Document;
 class Node;
+class TextNode;
 class Posting;
 class Mrl;
 class Surface;
@@ -320,7 +321,7 @@ public:
     virtual ~Node ();
     Document * document ();
     virtual Mrl * mrl ();
-    virtual NodePtr childFromTag (const String & tag);
+    virtual Node *childFromTag (const String & tag);
     void characterData (const String & s);
     String innerText () const;
     String innerXML () const;
@@ -520,7 +521,7 @@ inline KDE_NO_EXPORT T * convertNode (NodePtr e) {
 class KMPLAYER_EXPORT Mrl : public Element {
 protected:
     Mrl (NodePtr & d, short id=0);
-    NodePtr childFromTag (const String & tag);
+    Node *childFromTag (const String & tag);
     void parseParam (const TrieString &, const String &);
     unsigned int cached_ismrl_version;
     PlayType cached_play_type;
@@ -532,7 +533,6 @@ public:
      */
     virtual Mrl * linkNode ();
     virtual Mrl * mrl ();
-    virtual void endOfFile ();
     String absolutePath ();
 
     virtual void activate ();
@@ -540,6 +540,7 @@ public:
     virtual void defer ();
     virtual void undefer ();
     virtual void deactivate ();
+    virtual void *message (MessageType msg, void *content=NULL);
     /**
      * By default support one event handler (eg. SMIL or RP child document)
      */
@@ -713,7 +714,7 @@ public:
      * so explicitly dispose it (calls clear and set m_doc to 0L)
      * */
     void dispose ();
-    virtual NodePtr childFromTag (const String & tag);
+    virtual Node *childFromTag (const String & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "document"; }
     virtual void activate ();
     virtual void defer ();
@@ -760,6 +761,76 @@ private:
     int cur_time_interval;
 };
 
+namespace SMIL {
+    class Smil;
+    class Layout;
+    class RegionBase;
+    class Seq;
+    class Par;
+    class Excl;
+    class Transition;
+    class Animate;
+    class AnimateMotion;
+    class MediaType;
+    class ImageMediaType;
+    class TextMediaType;
+    class RefMediaType;
+    class AVMediaType;
+    class Brush;
+    class SmilText;
+    class TextFlow;
+    class PriorityClass;
+    class Anchor;
+    class Area;
+}
+namespace RP {
+    class Imfl;
+    class Crossfade;
+    class Fadein;
+    class Fadeout;
+    class Fill;
+    class Wipe;
+    class ViewChange;
+    class Animate;
+}
+
+class KMPLAYER_NO_EXPORT Visitor {
+public:
+    KDE_NO_CDTOR_EXPORT Visitor () {}
+    KDE_NO_CDTOR_EXPORT virtual ~Visitor () {}
+    virtual void visit (Node *) {}
+    virtual void visit (TextNode *);
+    virtual void visit (Element *);
+    virtual void visit (SMIL::Smil *) {}
+    virtual void visit (SMIL::Layout *);
+    virtual void visit (SMIL::RegionBase *);
+    virtual void visit (SMIL::Seq *);
+    virtual void visit (SMIL::Par *);
+    virtual void visit (SMIL::Excl *);
+    virtual void visit (SMIL::Transition *);
+    virtual void visit (SMIL::Animate *);
+    virtual void visit (SMIL::AnimateMotion *);
+    virtual void visit (SMIL::PriorityClass *);
+    virtual void visit (SMIL::MediaType *);
+    virtual void visit (SMIL::ImageMediaType *);
+    virtual void visit (SMIL::TextMediaType *);
+    virtual void visit (SMIL::RefMediaType *);
+    virtual void visit (SMIL::AVMediaType *);
+    virtual void visit (SMIL::Brush *);
+    virtual void visit (SMIL::SmilText *);
+    virtual void visit (SMIL::TextFlow *);
+    virtual void visit (SMIL::Anchor *);
+    virtual void visit (SMIL::Area *);
+    virtual void visit (RP::Imfl *) {}
+    virtual void visit (RP::Crossfade *) {}
+    virtual void visit (RP::Fadein *) {}
+    virtual void visit (RP::Fadeout *) {}
+    virtual void visit (RP::Fill *) {}
+    virtual void visit (RP::Wipe *) {}
+    virtual void visit (RP::ViewChange *) {}
+    virtual void visit (RP::Animate *) {}
+};
+
 /**
  * Represents XML text, like "some text" in '<foo>some text</foo>'
  */
@@ -769,6 +840,7 @@ public:
     KDE_NO_CDTOR_EXPORT ~TextNode () {}
     void appendText (const String & s);
     void setText (const String & txt) { text = txt; }
+    void accept (Visitor *v) { v->visit (this); }
     const char * nodeName () const { return "#text"; }
     String nodeValue () const;
     bool expose () const;
@@ -794,77 +866,12 @@ public:
     DarkNode (NodePtr & d, const String & n, short id=0);
     KDE_NO_CDTOR_EXPORT ~DarkNode () {}
     const char * nodeName () const { return (const char *) name; }
-    NodePtr childFromTag (const String & tag);
+    Node *childFromTag (const String & tag);
     virtual bool expose () const;
 protected:
     String name;
 };
 
-namespace SMIL {
-    class Smil;
-    class Layout;
-    class RegionBase;
-    class Seq;
-    class Par;
-    class Excl;
-    class Transition;
-    class Animate;
-    class AnimateMotion;
-    class MediaType;
-    class ImageMediaType;
-    class TextMediaType;
-    class RefMediaType;
-    class AVMediaType;
-    class Brush;
-    class PriorityClass;
-    class Anchor;
-    class Area;
-}
-namespace RP {
-    class Imfl;
-    class Crossfade;
-    class Fadein;
-    class Fadeout;
-    class Fill;
-    class Wipe;
-    class ViewChange;
-    class Animate;
-}
-
-class KMPLAYER_NO_EXPORT Visitor {
-public:
-    KDE_NO_CDTOR_EXPORT Visitor () {}
-    KDE_NO_CDTOR_EXPORT virtual ~Visitor () {}
-    virtual void visit (Node *) {}
-    virtual void visit (Element *);
-    virtual void visit (SMIL::Smil *) {}
-    virtual void visit (SMIL::Layout *);
-    virtual void visit (SMIL::RegionBase *);
-    virtual void visit (SMIL::Seq *);
-    virtual void visit (SMIL::Par *);
-    virtual void visit (SMIL::Excl *);
-    virtual void visit (SMIL::Transition *);
-    virtual void visit (SMIL::Animate *);
-    virtual void visit (SMIL::AnimateMotion *);
-    virtual void visit (SMIL::PriorityClass *);
-    virtual void visit (SMIL::MediaType *);
-    virtual void visit (SMIL::ImageMediaType *);
-    virtual void visit (SMIL::TextMediaType *);
-    virtual void visit (SMIL::RefMediaType *);
-    virtual void visit (SMIL::AVMediaType *);
-    virtual void visit (SMIL::Brush *);
-    virtual void visit (SMIL::Anchor *);
-    virtual void visit (SMIL::Area *);
-    virtual void visit (RP::Imfl *) {}
-    virtual void visit (RP::Crossfade *) {}
-    virtual void visit (RP::Fadein *) {}
-    virtual void visit (RP::Fadeout *) {}
-    virtual void visit (RP::Fill *) {}
-    virtual void visit (RP::Wipe *) {}
-    virtual void visit (RP::ViewChange *) {}
-    virtual void visit (RP::Animate *) {}
-};
-
 //-----------------------------------------------------------------------------
 
 /**
