@@ -1626,6 +1626,8 @@ KMPLAYER_NO_EXPORT void Downloader::jobData (Job *jb, ByteArray & data) {
     bytes += data.size ();
     if (size > 0)
         m_notify->setLoading ((int) (100.0 * bytes / size));
+    else if (data.size () == bytes)
+         m_notify->setLoading (0);
     if (data.size ())
         write (fd, data.data (), data.size ());
 }
